@@ -22,7 +22,6 @@
 #define AGENTMANAGER_H
 
 #include <QHash>
-#include <QMap>
 #include <QStringList>
 
 #include "agenttype.h"
@@ -33,7 +32,8 @@ class QDir;
 class QFileSystemWatcher;
 #endif
 
-namespace Akonadi {
+namespace Akonadi
+{
 class ProcessControl;
 }
 
@@ -53,7 +53,7 @@ public:
      *
      * @param parent The parent object.
      */
-    explicit AgentManager(bool verbose, QObject *parent = Q_NULLPTR);
+    explicit AgentManager(bool verbose, QObject *parent = nullptr);
 
     /**
      * Destroys the agent manager.
