@@ -29,7 +29,6 @@
 
 #include <shared/akapplication.h>
 
-
 #include "controlmanagerinterface.h"
 #include "janitorinterface.h"
 #include "akonadistarter.h"
@@ -53,7 +52,7 @@
 static bool startServer(bool verbose)
 {
     if (QDBusConnection::sessionBus().interface()->isServiceRegistered(Akonadi::DBus::serviceName(Akonadi::DBus::Control))
-        || QDBusConnection::sessionBus().interface()->isServiceRegistered(Akonadi::DBus::serviceName(Akonadi::DBus::Server))) {
+            || QDBusConnection::sessionBus().interface()->isServiceRegistered(Akonadi::DBus::serviceName(Akonadi::DBus::Server))) {
         std::cerr << "Akonadi is already running." << std::endl;
         return false;
     }
@@ -64,8 +63,8 @@ static bool startServer(bool verbose)
 static bool stopServer()
 {
     org::freedesktop::Akonadi::ControlManager iface(Akonadi::DBus::serviceName(Akonadi::DBus::Control),
-                                                    QStringLiteral("/ControlManager"),
-                                                    QDBusConnection::sessionBus(), 0);
+            QStringLiteral("/ControlManager"),
+            QDBusConnection::sessionBus(), nullptr);
     if (!iface.isValid()) {
         std::cerr << "Akonadi is not running." << std::endl;
         return false;
@@ -100,10 +99,10 @@ static bool checkSearchSupportStatus()
         searchMethods << pluginOverride;
     } else {
         const QStringList dirs = Akonadi::XdgBaseDirs::findPluginDirs();
-        Q_FOREACH (const QString &pluginDir, dirs) {
+        for (const QString &pluginDir : dirs) {
             QDir dir(pluginDir + QLatin1String("/akonadi"));
             const QStringList desktopFiles = dir.entryList(QStringList() << QStringLiteral("*.desktop"), QDir::Files);
-            Q_FOREACH (const QString &desktopFileName, desktopFiles) {
+            for (const QString &desktopFileName : desktopFiles) {
                 QSettings desktop(pluginDir + QLatin1String("/akonadi/") + desktopFileName, QSettings::IniFormat);
                 desktop.beginGroup(QStringLiteral("Desktop Entry"));
                 if (desktop.value(QStringLiteral("Type")).toString() != QLatin1String("AkonadiSearchPlugin")) {
@@ -127,10 +126,10 @@ static bool checkAvailableAgentTypes()
 {
     const QStringList dirs = Akonadi::XdgBaseDirs::findAllResourceDirs("data", QStringLiteral("akonadi/agents"));
     QStringList types;
-    Q_FOREACH (const QString &pluginDir, dirs) {
+    for (const QString &pluginDir : dirs) {
         QDir dir(pluginDir);
         const QStringList plugins = dir.entryList(QStringList() << QStringLiteral("*.desktop"), QDir::Files);
-        Q_FOREACH (const QString &plugin, plugins) {
+        for (const QString &plugin : plugins) {
             QSettings pluginInfo(pluginDir + QLatin1String("/") + plugin, QSettings::IniFormat);
             pluginInfo.beginGroup(QStringLiteral("Desktop Entry"));
             types << pluginInfo.value(QStringLiteral("X-Akonadi-Identifier")).toString();
@@ -163,16 +162,16 @@ static bool statusServer()
 static void runJanitor(const QString &operation)
 {
     org::freedesktop::Akonadi::Janitor janitor(Akonadi::DBus::serviceName(Akonadi::DBus::StorageJanitor),
-                                               QStringLiteral(AKONADI_DBUS_STORAGEJANITOR_PATH),
-                                               QDBusConnection::sessionBus());
+            QStringLiteral(AKONADI_DBUS_STORAGEJANITOR_PATH),
+            QDBusConnection::sessionBus());
     QObject::connect(&janitor, &org::freedesktop::Akonadi::Janitor::information,
-                        [](const QString &msg) {
-                            std::cerr << msg.toStdString() << std::endl;
-                        });
+    [](const QString & msg) {
+        std::cerr << msg.toStdString() << std::endl;
+    });
     QObject::connect(&janitor, &org::freedesktop::Akonadi::Janitor::done,
-                     []() {
-                         qApp->exit();
-                     });
+    []() {
+        qApp->exit();
+    });
     janitor.asyncCall(operation);
     qApp->exec();
 }
@@ -182,16 +181,15 @@ int main(int argc, char **argv)
     AkCoreApplication app(argc, argv);
 
     app.setDescription(QStringLiteral("Akonadi server manipulation tool\n\n"
-                                     "Commands:\n"
-                                     "  start          Starts the Akonadi server with all its processes\n"
-                                     "  stop           Stops the Akonadi server and all its processes cleanly\n"
-                                     "  restart        Restart Akonadi server with all its processes\n"
-                                     "  status         Shows a status overview of the Akonadi server\n"
-                                     "  vacuum         Vacuum internal storage (WARNING: needs a lot of time and disk\n"
-                                     "                 space!)\n"
-                                     "  fsck           Check (and attempt to fix) consistency of the internal storage\n"
-                                     "                 (can take some time)"));
-
+                                      "Commands:\n"
+                                      "  start          Starts the Akonadi server with all its processes\n"
+                                      "  stop           Stops the Akonadi server and all its processes cleanly\n"
+                                      "  restart        Restart Akonadi server with all its processes\n"
+                                      "  status         Shows a status overview of the Akonadi server\n"
+                                      "  vacuum         Vacuum internal storage (WARNING: needs a lot of time and disk\n"
+                                      "                 space!)\n"
+                                      "  fsck           Check (and attempt to fix) consistency of the internal storage\n"
+                                      "                 (can take some time)"));
 
     KAboutData aboutData(QStringLiteral("akonadictl"),
                          QStringLiteral("akonadictl"),
