@@ -19,6 +19,7 @@
 
 #include "changerecorder_p.h"
 #include "akonadicore_debug.h"
+#include "helper_p.h"
 
 #include <QFile>
 #include <QDir>
@@ -31,7 +32,7 @@ using namespace Akonadi;
 ChangeRecorderPrivate::ChangeRecorderPrivate(ChangeNotificationDependenciesFactory *dependenciesFactory_,
         ChangeRecorder *parent)
     : MonitorPrivate(dependenciesFactory_, parent)
-    , settings(0)
+    , settings(nullptr)
     , enableChangeRecording(true)
     , m_lastKnownNotificationsCount(0)
     , m_startOffset(0)
@@ -94,6 +95,7 @@ void ChangeRecorderPrivate::loadNotifications()
                 break;
             case Collection:
                 msg = loadCollectionNotification(settings);
+                break;
             case Tag:
             case Relation:
             case InvalidType:
@@ -212,7 +214,7 @@ QString ChangeRecorderPrivate::dumpNotificationListToString() const
     QString result;
     bool dummy;
     const QQueue<Protocol::ChangeNotification> notifications = loadFrom(&file, dummy);
-    Q_FOREACH (const Protocol::ChangeNotification &n, notifications) {
+    for (const Protocol::ChangeNotification &n : notifications) {
         result += n.debugString() + QLatin1Char('\n');
     }
     return result;
@@ -227,16 +229,16 @@ void ChangeRecorderPrivate::addToStream(QDataStream &stream, const Protocol::Cha
     stream << int(mapToLegacyType(msg.type()));
     switch (msg.type()) {
     case Protocol::Command::ItemChangeNotification:
-        saveItemNotification(stream, static_cast<const Protocol::ItemChangeNotification&>(msg));
+        saveItemNotification(stream, static_cast<const Protocol::ItemChangeNotification &>(msg));
         break;
     case Protocol::Command::CollectionChangeNotification:
-        saveCollectionNotification(stream, static_cast<const Protocol::CollectionChangeNotification&>(msg));
+        saveCollectionNotification(stream, static_cast<const Protocol::CollectionChangeNotification &>(msg));
         break;
     case Protocol::Command::TagChangeNotification:
-        saveTagNotification(stream, static_cast<const Protocol::TagChangeNotification&>(msg));
+        saveTagNotification(stream, static_cast<const Protocol::TagChangeNotification &>(msg));
         break;
     case Protocol::Command::RelationChangeNotification:
-        saveRelationNotification(stream, static_cast<const Protocol::RelationChangeNotification&>(msg));
+        saveRelationNotification(stream, static_cast<const Protocol::RelationChangeNotification &>(msg));
         break;
     default:
         qWarning() << "Unexpected type?";
@@ -317,8 +319,8 @@ void ChangeRecorderPrivate::notificationsEnqueued(int count)
         m_lastKnownNotificationsCount += count;
         if (m_lastKnownNotificationsCount != pendingNotifications.count()) {
             qCWarning(AKONADICORE_LOG) << this << "The number of pending notifications changed without telling us! Expected"
-                       << m_lastKnownNotificationsCount << "but got" << pendingNotifications.count()
-                       << "Caller just added" << count;
+                                       << m_lastKnownNotificationsCount << "but got" << pendingNotifications.count()
+                                       << "Caller just added" << count;
             Q_ASSERT(pendingNotifications.count() == m_lastKnownNotificationsCount);
         }
 
@@ -373,8 +375,7 @@ bool ChangeRecorderPrivate::emitNotification(const Protocol::ChangeNotification
     return someoneWasListening;
 }
 
-
-Protocol::ChangeNotification ChangeRecorderPrivate::loadItemNotification(QSettings* settings) const
+Protocol::ChangeNotification ChangeRecorderPrivate::loadItemNotification(QSettings *settings) const
 {
     Protocol::ItemChangeNotification msg;
     msg.setSessionId(settings->value(QStringLiteral("sessionId")).toByteArray());
@@ -388,15 +389,14 @@ Protocol::ChangeNotification ChangeRecorderPrivate::loadItemNotification(QSettin
     msg.setParentDestCollection(settings->value(QStringLiteral("parentDestCol")).toLongLong());
     const QStringList list = settings->value(QStringLiteral("itemParts")).toStringList();
     QSet<QByteArray> itemParts;
-    Q_FOREACH (const QString &entry, list) {
+    for (const QString &entry : list) {
         itemParts.insert(entry.toLatin1());
     }
     msg.setItemParts(itemParts);
     return msg;
 }
 
-
-Protocol::ChangeNotification ChangeRecorderPrivate::loadCollectionNotification(QSettings* settings) const
+Protocol::ChangeNotification ChangeRecorderPrivate::loadCollectionNotification(QSettings *settings) const
 {
     Protocol::CollectionChangeNotification msg;
     msg.setSessionId(settings->value(QStringLiteral("sessionId")).toByteArray());
@@ -408,7 +408,7 @@ Protocol::ChangeNotification ChangeRecorderPrivate::loadCollectionNotification(Q
     msg.setParentDestCollection(settings->value(QStringLiteral("parentDestCol")).toLongLong());
     const QStringList list = settings->value(QStringLiteral("itemParts")).toStringList();
     QSet<QByteArray> changedParts;
-    Q_FOREACH (const QString &entry, list) {
+    for (const QString &entry : list) {
         changedParts.insert(entry.toLatin1());
     }
     msg.setChangedParts(changedParts);
@@ -437,7 +437,6 @@ QSet<Protocol::ItemChangeNotification::Relation> ChangeRecorderPrivate::extractR
     return relations;
 }
 
-
 Protocol::ChangeNotification ChangeRecorderPrivate::loadItemNotification(QDataStream &stream, quint64 version) const
 {
     QByteArray resource, destinationResource;
@@ -508,7 +507,7 @@ Protocol::ChangeNotification ChangeRecorderPrivate::loadItemNotification(QDataSt
 QSet<QByteArray> ChangeRecorderPrivate::encodeRelations(const QSet<Protocol::ItemChangeNotification::Relation> &relations) const
 {
     QSet<QByteArray> rv;
-    Q_FOREACH (const auto &rel, relations) {
+    for (const auto &rel : relations) {
         rv.insert("RELATION " + rel.type.toLatin1() + ' ' + QByteArray::number(rel.leftId) + ' ' + QByteArray::number(rel.rightId));
     }
     return rv;
@@ -519,7 +518,7 @@ void ChangeRecorderPrivate::saveItemNotification(QDataStream &stream, const Prot
     stream << int(msg.operation());
     const auto items = msg.items();
     stream << items.count();
-    Q_FOREACH (const Protocol::ItemChangeNotification::Item &item, items) {
+    for (const Protocol::ItemChangeNotification::Item &item : items) {
         stream << quint64(item.id);
         stream << item.remoteId;
         stream << item.remoteRevision;
@@ -600,7 +599,7 @@ Protocol::ChangeNotification ChangeRecorderPrivate::loadCollectionNotification(Q
     return msg;
 }
 
-void Akonadi::ChangeRecorderPrivate::saveCollectionNotification(QDataStream& stream, const Protocol::CollectionChangeNotification &msg)
+void Akonadi::ChangeRecorderPrivate::saveCollectionNotification(QDataStream &stream, const Protocol::CollectionChangeNotification &msg)
 {
     stream << int(msg.operation());
     stream << int(1);
@@ -678,7 +677,7 @@ Protocol::ChangeNotification ChangeRecorderPrivate::loadTagNotification(QDataStr
     return msg;
 }
 
-void Akonadi::ChangeRecorderPrivate::saveTagNotification(QDataStream& stream, const Protocol::TagChangeNotification &msg)
+void Akonadi::ChangeRecorderPrivate::saveTagNotification(QDataStream &stream, const Protocol::TagChangeNotification &msg)
 {
     stream << int(msg.operation());
     stream << int(1);
@@ -749,7 +748,7 @@ Protocol::ChangeNotification ChangeRecorderPrivate::loadRelationNotification(QDa
     } else {
         msg.setOperation(mapRelationOperation(static_cast<LegacyOp>(operation)));
     }
-    Q_FOREACH (const QByteArray &part, itemParts) {
+    for (const QByteArray &part : qAsConst(itemParts)) {
         const QByteArrayList p = part.split(' ');
         if (p.size() < 2) {
             continue;
@@ -767,7 +766,7 @@ Protocol::ChangeNotification ChangeRecorderPrivate::loadRelationNotification(QDa
     return msg;
 }
 
-void Akonadi::ChangeRecorderPrivate::saveRelationNotification(QDataStream& stream, const Protocol::RelationChangeNotification &msg)
+void Akonadi::ChangeRecorderPrivate::saveRelationNotification(QDataStream &stream, const Protocol::RelationChangeNotification &msg)
 {
     QSet<QByteArray> rv;
     rv.insert("LEFT " + QByteArray::number(msg.leftItem()));
