@@ -23,7 +23,6 @@
 
 #include <QEventLoop>
 #include <QCoreApplication>
-#include <QTimer>
 #include <QPointer>
 
 using namespace Akonadi;
@@ -54,7 +53,7 @@ class Q_DECL_HIDDEN Control::Private
 public:
     Private(Control *parent)
         : mParent(parent)
-        , mEventLoop(0)
+        , mEventLoop(nullptr)
         , mSuccess(false)
         , mStarting(false)
         , mStopping(false)
@@ -86,7 +85,7 @@ bool Control::Private::exec()
     mEventLoop = new QEventLoop(mParent);
     mEventLoop->exec();
     mEventLoop->deleteLater();
-    mEventLoop = 0;
+    mEventLoop = nullptr;
 
     if (!mSuccess) {
         qCWarning(AKONADICORE_LOG) << "Could not start/stop Akonadi!";
