@@ -21,7 +21,6 @@
 #define AKONADI_ITEM_P_H
 
 #include <QDateTime>
-#include <QMap>
 #include <QVarLengthArray>
 
 #include "itempayloadinternals_p.h"
@@ -99,8 +98,7 @@ public:
     }
 
 private:
-    struct _save_bool
-    {
+    struct _save_bool {
         void f()
         {
         }
@@ -224,8 +222,7 @@ public:
     }
 };
 
-struct TypedPayload
-{
+struct TypedPayload {
     clone_ptr<Internal::PayloadBase> payload;
     int sharedPointerId;
     int metaTypeId;
@@ -242,7 +239,7 @@ struct BySharedPointerAndMetaTypeID : std::unary_function<TypedPayload, bool> {
     bool operator()(const TypedPayload &tp) const
     {
         return (mtid == -1 || mtid == tp.metaTypeId)
-               && (spid == -1 || spid == tp.sharedPointerId) ;
+               && (spid == -1 || spid == tp.sharedPointerId);
     }
 };
 
@@ -254,7 +251,7 @@ namespace std
 {
 template <>
 inline void swap<Akonadi::_detail::TypedPayload>(Akonadi::_detail::TypedPayload &lhs,
-                                                 Akonadi::_detail::TypedPayload &rhs)
+        Akonadi::_detail::TypedPayload &rhs)
 {
     lhs.payload.swap(rhs.payload);
     swap(lhs.sharedPointerId, rhs.sharedPointerId);
@@ -268,11 +265,17 @@ namespace Akonadi
 typedef std::vector<_detail::TypedPayload> PayloadContainer;
 }
 
+#if QT_VERSION >= QT_VERSION_CHECK(5, 9, 0) // see qtbase e5e2629
+namespace QtPrivate {
+#endif
 // disable Q_FOREACH on PayloadContainer (b/c it likes to take copies and clone_ptr doesn't like that)
 template <>
 class QForeachContainer<Akonadi::PayloadContainer>
 {
 };
+#if QT_VERSION >= QT_VERSION_CHECK(5, 9, 0)
+}
+#endif
 
 namespace Akonadi
 {
@@ -287,7 +290,7 @@ public:
         : QSharedData()
         , mRevision(-1)
         , mId(id)
-        , mParent(Q_NULLPTR)
+        , mParent(nullptr)
         , mLegacyPayload()
         , mPayloads()
         , mCollectionId(-1)
@@ -303,7 +306,7 @@ public:
 
     ItemPrivate(const ItemPrivate &other)
         : QSharedData(other)
-        , mParent(Q_NULLPTR)
+        , mParent(nullptr)
     {
         mId = other.mId;
         mRemoteId = other.mRemoteId;
@@ -367,8 +370,8 @@ public:
     Internal::PayloadBase *payloadBaseImpl(int spid, int mtid) const
     {
         auto it = std::find_if(mPayloads.cbegin(), mPayloads.cend(),
-                                _detail::BySharedPointerAndMetaTypeID(spid, mtid));
-        return it == mPayloads.cend() ? 0 : it->payload.get() ;
+                               _detail::BySharedPointerAndMetaTypeID(spid, mtid));
+        return it == mPayloads.cend() ? 0 : it->payload.get();
     }
 
     bool movePayloadFrom(ItemPrivate *other, int mtid) const    /*sic!*/
@@ -382,13 +385,13 @@ public:
         using namespace std; // for swap()
         for (PayloadContainer::iterator
                 dst = mPayloads.begin() + oldSize,
-                src = oPayloads.begin(), end = oPayloads.end() ; src != end ; ++src) {
+                src = oPayloads.begin(), end = oPayloads.end(); src != end; ++src) {
             if (matcher(*src)) {
                 swap(*dst, *src);
                 ++dst;
             }
         }
-        return numMatching > 0 ;
+        return numMatching > 0;
     }
 
 #if 0
