@@ -18,6 +18,7 @@
 */
 
 #include "pastehelper_p.h"
+#include "helper_p.h"
 
 #include "collectioncopyjob.h"
 #include "collectionmovejob.h"
@@ -39,8 +40,6 @@
 
 #include <QByteArray>
 #include <QMimeData>
-#include <QStringList>
-#include <QMutexLocker>
 
 #include <functional>
 
@@ -54,7 +53,7 @@ public:
     explicit PasteHelperJob(Qt::DropAction action, const Akonadi::Item::List &items,
                             const Akonadi::Collection::List &collections,
                             const Akonadi::Collection &destination,
-                            QObject *parent = Q_NULLPTR);
+                            QObject *parent = nullptr);
     virtual ~PasteHelperJob();
 
 private Q_SLOTS:
@@ -93,10 +92,10 @@ PasteHelperJob::PasteHelperJob(Qt::DropAction action, const Item::List &items,
         // Check if all items have the same parent collection ID
         const Collection parent = items.first().parentCollection();
         if (std::find_if(items.constBegin(), items.constEnd(),
-                         [parent](const Item &item) -> bool {
-                             return item.parentCollection() != parent;
-                         })
-                == items.constEnd()) {
+        [parent](const Item & item) -> bool {
+        return item.parentCollection() != parent;
+        })
+        == items.constEnd()) {
             dragSourceCollection = parent;
         }
 
@@ -204,12 +203,12 @@ void PasteHelperJob::runCollectionsActions()
 
     switch (mAction) {
     case Qt::CopyAction:
-        foreach (const Collection &col, mCollections) {   // FIXME: remove once we have a batch job for collections as well
+        for (const Collection &col : qAsConst(mCollections)) {   // FIXME: remove once we have a batch job for collections as well
             new CollectionCopyJob(col, mDestCollection, this);
         }
         break;
     case Qt::MoveAction:
-        foreach (const Collection &col, mCollections) {   // FIXME: remove once we have a batch job for collections as well
+        for (const Collection &col : qAsConst(mCollections)) {   // FIXME: remove once we have a batch job for collections as well
             new CollectionMoveJob(col, mDestCollection, this);
         }
         break;
@@ -232,7 +231,7 @@ bool PasteHelper::canPaste(const QMimeData *mimeData, const Collection &collecti
     Collection::Rights neededRights = Collection::ReadOnly;
     if (mimeData->hasUrls()) {
         const QList<QUrl> urls = mimeData->urls();
-        foreach (const QUrl &url, urls) {
+        for (const QUrl &url : urls) {
             const QUrlQuery query(url);
             if (query.hasQueryItem(QStringLiteral("item"))) {
                 neededRights |= Collection::CanCreateItem;
@@ -248,7 +247,7 @@ bool PasteHelper::canPaste(const QMimeData *mimeData, const Collection &collecti
         // check that the target collection supports the mime types of the
         // items/collections that shall be pasted
         bool supportsMimeTypes = true;
-        foreach (const QUrl &url, urls) {
+        for (const QUrl &url : qAsConst(urls)) {
             const QUrlQuery query(url);
             // collections do not provide mimetype information, so ignore this check
             if (query.hasQueryItem(QStringLiteral("collection"))) {
@@ -275,12 +274,13 @@ bool PasteHelper::canPaste(const QMimeData *mimeData, const Collection &collecti
 KJob *PasteHelper::paste(const QMimeData *mimeData, const Collection &collection, bool copy, Session *session)
 {
     if (!canPaste(mimeData, collection)) {
-        return 0;
+        return nullptr;
     }
 
     // we try to drop data not coming with the akonadi:// url
     // find a type the target collection supports
-    foreach (const QString &type, mimeData->formats()) {
+    const QStringList lstFormats = mimeData->formats();
+    for (const QString &type : lstFormats) {
         if (!collection.contentMimeTypes().contains(type)) {
             continue;
         }
@@ -300,7 +300,7 @@ KJob *PasteHelper::paste(const QMimeData *mimeData, const Collection &collection
     }
 
     if (!mimeData->hasUrls()) {
-        return 0;
+        return nullptr;
     }
 
     // data contains an url list
@@ -310,17 +310,17 @@ KJob *PasteHelper::paste(const QMimeData *mimeData, const Collection &collection
 KJob *PasteHelper::pasteUriList(const QMimeData *mimeData, const Collection &destination, Qt::DropAction action, Session *session)
 {
     if (!mimeData->hasUrls()) {
-        return 0;
+        return nullptr;
     }
 
     if (!canPaste(mimeData, destination)) {
-        return 0;
+        return nullptr;
     }
 
     const QList<QUrl> urls = mimeData->urls();
     Collection::List collections;
     Item::List items;
-    foreach (const QUrl &url, urls) {
+    for (const QUrl &url : urls) {
         const QUrlQuery query(url);
         const Collection collection = Collection::fromUrl(url);
         if (collection.isValid()) {
