@@ -60,27 +60,27 @@ class QSQLiteDriver : public QSqlDriver
     Q_OBJECT
     friend class QSQLiteResult;
 public:
-    explicit QSQLiteDriver(QObject *parent = Q_NULLPTR);
-    explicit QSQLiteDriver(sqlite3 *connection, QObject *parent = Q_NULLPTR);
+    explicit QSQLiteDriver(QObject *parent = nullptr);
+    explicit QSQLiteDriver(sqlite3 *connection, QObject *parent = nullptr);
     ~QSQLiteDriver();
-    bool hasFeature(DriverFeature f) const;
-    bool open(const QString & db,
-                   const QString & user,
-                   const QString & password,
-                   const QString & host,
-                   int port,
-                   const QString & connOpts);
-    void close();
-    QSqlResult *createResult() const;
-    bool beginTransaction();
-    bool commitTransaction();
-    bool rollbackTransaction();
-    QStringList tables(QSql::TableType) const;
+    bool hasFeature(DriverFeature f) const Q_DECL_OVERRIDE;
+    bool open(const QString &db,
+              const QString &user,
+              const QString &password,
+              const QString &host,
+              int port,
+              const QString &connOpts) Q_DECL_OVERRIDE;
+    void close() Q_DECL_OVERRIDE;
+    QSqlResult *createResult() const Q_DECL_OVERRIDE;
+    bool beginTransaction() Q_DECL_OVERRIDE;
+    bool commitTransaction() Q_DECL_OVERRIDE;
+    bool rollbackTransaction() Q_DECL_OVERRIDE;
+    QStringList tables(QSql::TableType) const Q_DECL_OVERRIDE;
 
-    QSqlRecord record(const QString& tablename) const;
-    QSqlIndex primaryIndex(const QString &table) const;
-    QVariant handle() const;
-    QString escapeIdentifier(const QString &identifier, IdentifierType) const;
+    QSqlRecord record(const QString &tablename) const Q_DECL_OVERRIDE;
+    QSqlIndex primaryIndex(const QString &table) const Q_DECL_OVERRIDE;
+    QVariant handle() const Q_DECL_OVERRIDE;
+    QString escapeIdentifier(const QString &identifier, IdentifierType) const Q_DECL_OVERRIDE;
 
 private:
     Q_DECLARE_PRIVATE(QSQLiteDriver)
