@@ -55,25 +55,24 @@
 #include <QSettings>
 #include <QTimer>
 #include <QDBusServiceWatcher>
-#include <QLocalServer>
 
 using namespace Akonadi;
 using namespace Akonadi::Server;
 
-AkonadiServer *AkonadiServer::s_instance = 0;
+AkonadiServer *AkonadiServer::s_instance = nullptr;
 
 AkonadiServer::AkonadiServer(QObject *parent)
     : QObject(parent)
-    , mCmdServer(Q_NULLPTR)
-    , mNtfServer(Q_NULLPTR)
-    , mNotificationManager(Q_NULLPTR)
-    , mCacheCleaner(Q_NULLPTR)
-    , mIntervalCheck(Q_NULLPTR)
-    , mStorageJanitor(Q_NULLPTR)
-    , mItemRetrieval(Q_NULLPTR)
-    , mAgentSearchManager(Q_NULLPTR)
-    , mDatabaseProcess(0)
-    , mSearchManager(0)
+    , mCmdServer(nullptr)
+    , mNtfServer(nullptr)
+    , mNotificationManager(nullptr)
+    , mCacheCleaner(nullptr)
+    , mIntervalCheck(nullptr)
+    , mStorageJanitor(nullptr)
+    , mItemRetrieval(nullptr)
+    , mAgentSearchManager(nullptr)
+    , mDatabaseProcess(nullptr)
+    , mSearchManager(nullptr)
     , mAlreadyShutdown(false)
 {
     // Register bunch of useful types
@@ -239,7 +238,7 @@ bool AkonadiServer::init()
     mAgentSearchManager = new SearchTaskManager();
 
     const QStringList searchManagers = settings.value(QStringLiteral("Search/Manager"),
-                                                      QStringList() << QStringLiteral("Agent")).toStringList();
+                                       QStringList() << QStringLiteral("Agent")).toStringList();
     mSearchManager = new SearchManager(searchManagers);
 
     new ServerAdaptor(this);
@@ -251,8 +250,8 @@ bool AkonadiServer::init()
     }
 
     QDBusServiceWatcher *watcher = new QDBusServiceWatcher(DBus::serviceName(DBus::Control),
-                                                           QDBusConnection::sessionBus(),
-                                                           QDBusServiceWatcher::WatchForOwnerChange, this);
+            QDBusConnection::sessionBus(),
+            QDBusServiceWatcher::WatchForOwnerChange, this);
 
     connect(watcher, &QDBusServiceWatcher::serviceOwnerChanged,
             this, &AkonadiServer::serviceOwnerChanged);
@@ -284,13 +283,12 @@ AkonadiServer::~AkonadiServer()
 
 template <typename T> static void quitThread(T &thread)
 {
-    if (!thread) {
-        return;
+    if (thread) {
+        thread->quit();
+        thread->wait();
+        delete thread;
+        thread = nullptr;
     }
-    thread->quit();
-    thread->wait();
-    delete thread;
-    thread = 0;
 }
 
 bool AkonadiServer::quit()
@@ -325,7 +323,7 @@ bool AkonadiServer::quit()
         stopDatabaseProcess();
     }
 
-    QSettings settings(StandardDirs::serverConfigFile(), QSettings::IniFormat);
+    //QSettings settings(StandardDirs::serverConfigFile(), QSettings::IniFormat);
     const QString connectionSettingsFile = StandardDirs::connectionConfigFile(XdgBaseDirs::WriteOnly);
 
     if (!QDir::home().remove(connectionSettingsFile)) {
@@ -356,7 +354,7 @@ void AkonadiServer::newCmdConnection(quintptr socketDescriptor)
 
 void AkonadiServer::connectionDisconnected()
 {
-    auto conn = qobject_cast<Connection*>(sender());
+    auto conn = qobject_cast<Connection *>(sender());
     mConnections.removeOne(conn);
     delete conn;
 }
