@@ -21,15 +21,16 @@
 #define AKONADI_SERVER_COLLECTIONSCHEDULER_H
 
 #include <QThread>
-#include <QTimer>
 #include <QMultiMap>
 #include <QMutex>
 
 #include "entities.h"
 #include "akthread.h"
 
-namespace Akonadi {
-namespace Server {
+namespace Akonadi
+{
+namespace Server
+{
 
 class Collection;
 class PauseableTimer;
@@ -39,7 +40,7 @@ class CollectionScheduler : public AkThread
     Q_OBJECT
 
 public:
-    explicit CollectionScheduler(QThread::Priority priority, QObject *parent = Q_NULLPTR);
+    explicit CollectionScheduler(const QString &threadName, QThread::Priority priority, QObject *parent = nullptr);
     virtual ~CollectionScheduler();
 
     void collectionChanged(qint64 collectionId);
