@@ -21,8 +21,10 @@
 
 #include "handler.h"
 
-namespace Akonadi {
-namespace Server {
+namespace Akonadi
+{
+namespace Server
+{
 
 /**
   @ingroup akonadi_server_handler
