@@ -17,14 +17,15 @@
  *
  */
 
-
 #ifndef AKONADI_SEARCHRESULT_H
 #define AKONADI_SEARCHRESULT_H
 
 #include "handler.h"
 
-namespace Akonadi {
-namespace Server {
+namespace Akonadi
+{
+namespace Server
+{
 
 /**
   @ingroup akonadi_server_handler
