@@ -43,7 +43,7 @@ bool TagStore::parseStream()
     // Retrieve all tag's attributes
     const TagAttribute::List attributes = TagAttribute::retrieveFiltered(TagAttribute::tagIdFullColumnName(), cmd.tagId());
     QMap<QByteArray, TagAttribute> attributesMap;
-    Q_FOREACH (const TagAttribute &attribute, attributes) {
+    for (const TagAttribute &attribute : attributes) {
         attributesMap.insert(attribute.type(), attribute);
     }
 
@@ -76,7 +76,7 @@ bool TagStore::parseStream()
         //Simply using remove() doesn't work since we need two arguments
         QueryBuilder qb(TagRemoteIdResourceRelation::tableName(), QueryBuilder::Delete);
         qb.addValueCondition(TagRemoteIdResourceRelation::tagIdColumn(), Query::Equals, cmd.tagId());
-        qb.addValueCondition(TagRemoteIdResourceRelation::resourceIdColumn(), Query::Equals,connection()->context()->resource().id());
+        qb.addValueCondition(TagRemoteIdResourceRelation::resourceIdColumn(), Query::Equals, connection()->context()->resource().id());
         qb.exec();
 
         if (!cmd.remoteId().isEmpty()) {
