@@ -22,10 +22,10 @@
 
 #include "dbconfig.h"
 
-class QProcess;
-
-namespace Akonadi {
-namespace Server {
+namespace Akonadi
+{
+namespace Server
+{
 
 class DbConfigPostgresql : public DbConfig
 {
