@@ -24,16 +24,16 @@
 #include "schematypes.h"
 
 #include <QHash>
-#include <QPair>
-#include <QVector>
 #include <QStringList>
 #include <QSharedPointer>
 #include <QSqlDatabase>
 
 class DbInitializerTest;
 
-namespace Akonadi {
-namespace Server {
+namespace Akonadi
+{
+namespace Server
+{
 
 class Schema;
 
@@ -62,7 +62,7 @@ public:
     /**
       Returns an initializer instance for a given backend.
     */
-    static DbInitializer::Ptr createInstance(const QSqlDatabase &database, Schema *schema = Q_NULLPTR);
+    static DbInitializer::Ptr createInstance(const QSqlDatabase &database, Schema *schema = nullptr);
 
     /**
      * Destroys the database initializer.
