@@ -20,16 +20,16 @@
 #ifndef PARTHELPER_H
 #define PARTHELPER_H
 
-#include <QtGlobal>
 #include "entities.h"
 #include "../exception.h"
 
 class QString;
 class QVariant;
-class QFile;
 
-namespace Akonadi {
-namespace Server {
+namespace Akonadi
+{
+namespace Server
+{
 
 AKONADI_EXCEPTION_MAKE_INSTANCE(PartHelperException);
 
@@ -41,7 +41,8 @@ AKONADI_EXCEPTION_MAKE_INSTANCE(PartHelperException);
  * @todo Use exceptions for error handling in all these methods. Requires that all callers
  * can handle that first though.
  */
-namespace PartHelper {
+namespace PartHelper
+{
 /**
  * Update payload of an existing part @p part to @p data and size @p dataSize.
  * Automatically decides whether or not the data should be stored in the database
@@ -55,7 +56,7 @@ void update(Part *part, const QByteArray &data, qint64 dataSize);
  * @p part must not be in the database yet (ie. valid() == false) and must have
  * a data size set.
  */
-bool insert(Part *part, qint64 *insertId = Q_NULLPTR);
+bool insert(Part *part, qint64 *insertId = nullptr);
 
 /** Deletes @p part from the database and also removes existing filesystem data if needed. */
 bool remove(Part *part);
