@@ -73,7 +73,6 @@ Protocol::PartMetaData PartStreamer::requestPartMetaData(const QByteArray &partN
     return Protocol::StreamPayloadResponse(cmd).metaData();
 }
 
-
 bool PartStreamer::streamPayload(Part &part, const QByteArray &partName)
 {
     Protocol::PartMetaData metaPart = requestPartMetaData(partName);
@@ -256,8 +255,8 @@ bool PartStreamer::preparePart(bool checkExists, const QByteArray &partName, Par
 
 bool PartStreamer::stream(bool checkExists, const QByteArray &partName, qint64 &partSize, bool *changed)
 {
-    mCheckChanged = (changed != 0);
-    if (changed != 0) {
+    mCheckChanged = (changed != nullptr);
+    if (changed != nullptr) {
         *changed = false;
     }
 
@@ -278,8 +277,8 @@ bool PartStreamer::stream(bool checkExists, const QByteArray &partName, qint64 &
 
 bool PartStreamer::streamAttribute(bool checkExists, const QByteArray &_partName, const QByteArray &value, bool *changed)
 {
-    mCheckChanged = (changed != 0);
-    if (changed != 0) {
+    mCheckChanged = (changed != nullptr);
+    if (changed != nullptr) {
         *changed = false;
     }
 
