@@ -35,9 +35,6 @@
 #include <kdescendantsproxymodel.h>
 
 #include <QAbstractItemModel>
-#include <QEvent>
-#include <QPointer>
-#include <QMouseEvent>
 
 using namespace Akonadi;
 
@@ -46,8 +43,8 @@ class Q_DECL_HIDDEN CollectionComboBox::Private
 public:
     Private(QAbstractItemModel *customModel, CollectionComboBox *parent)
         : mParent(parent)
-        , mMonitor(0)
-        , mModel(0)
+        , mMonitor(nullptr)
+        , mModel(nullptr)
     {
         if (customModel) {
             mBaseModel = customModel;
@@ -124,7 +121,7 @@ void CollectionComboBox::Private::activated(const QModelIndex &index)
 
 CollectionComboBox::CollectionComboBox(QWidget *parent)
     : QComboBox(parent)
-    , d(new Private(0, this))
+    , d(new Private(nullptr, this))
 {
 }
 
@@ -145,7 +142,7 @@ void CollectionComboBox::setMimeTypeFilter(const QStringList &contentMimeTypes)
     d->mMimeTypeFilterModel->addMimeTypeFilters(contentMimeTypes);
 
     if (d->mMonitor) {
-        foreach (const QString &mimeType, contentMimeTypes) {
+        for (const QString &mimeType : contentMimeTypes) {
             d->mMonitor->setMimeTypeMonitored(mimeType, true);
         }
     }
